from transformer.lib.errors import ClientError as Error
from transformer.lib.errors import (error_table, AuthenticationError, TimeIsSkewedError,
		WrongCredentialsError, NotEnoughRights, UnknownToken, ElapsedToken, WrongValue, UnknownResource, UnknownApplicationToken, ElapsedApplicationToken)
try:
    from unicorn.core.translation import _
except:
    class _(object):
        def __init__(self, text):
            self.text = text


class Offsets:
    BTSYNC = 6000
    OAUTH2 = 8000
    NETWORK = 4500
    GENERIC = 210
    ISCSI = 5000
    STORAGE = 5500
    MULTI_NIC = 4000
    SHARING = 2000
    SDRIVE = 7500
    SECURITY = 9400
    RESET_CREDENTIAL = 8100
    BIG_WUALA = 3000
    SETTINGS_BACKUP = 7000
    APPSTORE = 6500
    SERIALIZATION = 200
    DOWNLOAD = 9000
    POWERSAVE = 9100
    WELCOME = 500
    AUTHENTICATION = 0
    UNICORN = 1000
    FILESHARING = 8500
    URL_PROXY = 9200
    BACKUP = 9300

class TooManyTokens(Error):
    real_id  = 20

class MissingProperty(Error):
    real_id  = 201

class BadPropertyType(Error):
    real_id  = 202

class MalformedBody(Error):
    real_id  = 203

class WrongFunctionPrototype(Error):
    real_id  = 204

class UnexpectedProperty(Error):
    real_id  = 205

class NtpServerError(Error):
    real_id  = 222

class FileSystemFileNotExists(Error):
    real_id  = 230

class FileSystemFileAlreadyExists(Error):
    real_id  = 231

class FileSystemInvalidMove(Error):
    real_id  = 232

class FileSystemErrorMove(Error):
    real_id  = 233

class WelcomeAlreadyDone(Error):
    real_id  = 501

class WelcomeUserCreationFailed(Error):
    real_id  = 502

class WelcomeShareCreationFailed(Error):
    real_id  = 503

class WelcomeUserNotFound(Error):
    real_id  = 504

class InvalidRequestConfig(Error):
    real_id  = 1001

class UnicornSaveError(Error):
    real_id  = 1002

class QuotaNotAllowed(Error):
    real_id  = 2001

class BrowsingInvalidPath(Error):
    real_id  = 2005

class BrowsingWrongAccess(Error):
    real_id  = 2006

class BrowsingUnknownToken(Error):
    real_id  = 2007

class BrowsingAlreadyExists(Error):
    real_id  = 2008

class BrowsingWrongPassword(Error):
    real_id  = 2009

class ShareNotFound(Error):
    real_id  = 2010

class ShareNameException(Error):
    real_id  = 2011

class ShareNameAlreadyExists(Error):
    real_id  = 2012

class ShareForbidenName(Error):
    real_id  = 2013

class UserNotFound(Error):
    real_id  = 2020

class UserNameException(Error):
    real_id  = 2021

class UserNameAlreadyExists(Error):
    real_id  = 2022

class UserForbidenName(Error):
    real_id  = 2023

class WrongInputId(Error):
    real_id  = 2024

class DomainError(Error):
    real_id  = 2025

class GroupNotFound(Error):
    real_id  = 2030

class GroupNameException(Error):
    real_id  = 2031

class VolumeNotFound(Error):
    real_id  = 2032

class QuotaNotFound(Error):
    real_id  = 2033

class GroupForbiddenName(Error):
    real_id  = 2034

class MaxUserCountReached(Error):
    real_id  = 2035

class MaxShareCountReached(Error):
    real_id  = 2036

class PrinterNotFound(Error):
    real_id  = 2050

class CloudPrintCredentialsNotSet(Error):
    real_id  = 2051

class HostNotFound(Error):
    real_id  = 2100

class ServiceNotFound(Error):
    real_id  = 2101

class PortAlreadyInUse(Error):
    real_id  = 2102

class RemoteBackupActivationUserAlreadyExists(Error):
    real_id  = 2132

class NetBackupNotActive(Error):
    real_id  = 2133

class NetBackupAlreadyActive(Error):
    real_id  = 2134

class NetBackupAlreadyCreated(Error):
    real_id  = 2135

class NetBackupNotCreated(Error):
    real_id  = 2136

class TimeMachineNotActive(Error):
    real_id  = 2137

class TimeMachineAlreadyActive(Error):
    real_id  = 2138

class TimeMachineAlreadyCreated(Error):
    real_id  = 2139

class TimeMachineNotCreated(Error):
    real_id  = 2140

class UpsDeviceNotFound(Error):
    real_id  = 2150

class UnknownInvite(Error):
    real_id  = 2200

class EmailAlreadyInvited(Error):
    real_id  = 2201

class BwAlreadyExists(Error):
    real_id  = 3001

class BwDoesNotExists(Error):
    real_id  = 3002

class NetworkGenericError(Error):
    real_id  = 4000

class BackendGenericError(Error):
    real_id  = 4001

class InterfaceDeleteForbidden(Error):
    real_id  = 4002

class IDNotFound(Error):
    real_id  = 4003

class InvalidHostname(Error):
    real_id  = 4004

class InvalidWorkgroup(Error):
    real_id  = 4005

class InvalidProxyConfig(Error):
    real_id  = 4006

class InvalidBondingMode(Error):
    real_id  = 4007

class InvalidIPMode(Error):
    real_id  = 4008

class InvalidIPv4Address(Error):
    real_id  = 4009

class InvalidMonitorInterval(Error):
    real_id  = 4010

class InterfaceNotMaster(Error):
    real_id  = 4011

class BondingNotEnoughSlaves(Error):
    real_id  = 4012

class BondingPrimaryNotSlave(Error):
    real_id  = 4013

class InterfaceConfigIncomplete(Error):
    real_id  = 4014

class ReadOnlyAttribute(Error):
    real_id  = 4015

class HostnameLocked(Error):
    real_id  = 4016

class FriendlyNameAlreadyUsed(Error):
    real_id  = 4017

class BondingInterfaceNotFound(Error):
    real_id  = 4018

class InterfaceSlaveAlreadyUsed(Error):
    real_id  = 4019

class CannotDisableAllInterfaces(Error):
    real_id  = 4020

class InterfaceSlaveMissing(Error):
    real_id  = 4021

class CannotDisablePrimaryInterface(Error):
    real_id  = 4022

class InvalidIPv4Netmask(Error):
    real_id  = 4023

class InvalidIPv6Address(Error):
    real_id  = 4024

class ServiceByNicNotFound(Error):
    real_id  = 4030

class PortMappingNotFound(Error):
    real_id  = 4501

class IscsiUnExpectedError(Error):
    real_id  = 5000

class IscsiTargetNotFound(Error):
    real_id  = 5001

class IscsiTargetTotalCountExceeded(Error):
    real_id  = 5002

class IscsiTargetLunCountExceeded(Error):
    real_id  = 5003

class IscsiLunNotFound(Error):
    real_id  = 5051

class IscsiLunVolumeCountExceeded(Error):
    real_id  = 5052

class IscsiLunFileNotEnoughSpace(Error):
    real_id  = 5053

class IscsiLunFileExportFailed(Error):
    real_id  = 5054

class IscsiLunFileImportFailed(Error):
    real_id  = 5055

class IscsiLunFileDuplicateFailed(Error):
    real_id  = 5056

class IscsiLunFileOpNotCanceled(Error):
    real_id  = 5057

class IscsiLunFileSourceEmpty(Error):
    real_id  = 5058

class IscsiLunFileOpInProgress(Error):
    real_id  = 5059

class IscsiLunFileNoVolume(Error):
    real_id  = 5060

class IscsiLunFileSourceNotExist(Error):
    real_id  = 5061

class IscsiExternalVolumeError(Error):
    real_id  = 5062

class IscsiVolumeDisabledError(Error):
    real_id  = 5063

class IscsiLunFileDeleteError(Error):
    real_id  = 5064

class IscsiLunFilePartition(Error):
    real_id  = 5065

class IscsiLunFileAllocate(Error):
    real_id  = 5066

class IscsiLunFileSparse(Error):
    real_id  = 5067

class IscsiLunFileMaxSize(Error):
    real_id  = 5068

class IscsiLunShrinkNotAllowed(Error):
    real_id  = 5069

class IscsiLunBlockNoSize(Error):
    real_id  = 5070

class IscsiIqnInvalidFormat(Error):
    real_id  = 5071

class IscsiDuplicateIqn(Error):
    real_id  = 5072

class IscsiIqnBadCase(Error):
    real_id  = 5073

class IscsiLunBlockNoVolume(Error):
    real_id  = 5074

class IscsiLunInvalidType(Error):
    real_id  = 5101

class UnknownDevice(Error):
    real_id  = 5501

class no_slots(Error):
    real_id  = 5502

class no_free_space(Error):
    real_id  = 5503

class slots_not_new(Error):
    real_id  = 5504

class slots_already_used(Error):
    real_id  = 5505

class not_enough_slots(Error):
    real_id  = 5506

class partitionning_error(Error):
    real_id  = 5507

class raid_not_available(Error):
    real_id  = 5510

class no_encryption_password(Error):
    real_id  = 5520

class RaidBadPassword(Error):
    real_id  = 5521

class RaidBadMountpoint(Error):
    real_id  = 5522

class RaidWriteError(Error):
    real_id  = 5523

class RaidInvalidChar(Error):
    real_id  = 5524

class RaidWaitUnlockError(Error):
    real_id  = 5525

class RaidInvalidPasswordSize(Error):
    real_id  = 5526

class InvalidProtectDir(Error):
    real_id  = 5527

class UnknownPool(Error):
    real_id  = 5540

class UnknownSlot(Error):
    real_id  = 5541

class BtsyncShareCreationFailed(Error):
    real_id  = 6001

class BtsyncShareDeletionFailed(Error):
    real_id  = 6002

class BtsyncShareNotFound(Error):
    real_id  = 6003

class BtsyncGenSecretFailed(Error):
    real_id  = 6004

class AppStoreGenericError(Error):
    real_id  = 6510

class AppStoreConnectionError(Error):
    real_id  = 6511

class AppStoreMissingDependenciesError(Error):
    real_id  = 6512

class AppStoreAppNotFoundError(Error):
    real_id  = 6513

class AppStoreUpdateConflictingError(Error):
    real_id  = 6514

class AppStoreDownloadError(Error):
    real_id  = 6515

class AppStoreAppIsBrokenError(Error):
    real_id  = 6516

class AppStoreRainbowGenericError(Error):
    real_id  = 6517

class AppStorePortConflict1Error(Error):
    real_id  = 6518

class AppStorePortConflict2Error(Error):
    real_id  = 6519

class AppStorePortConflict3Error(Error):
    real_id  = 6520

class AppStorePortConflictsError(Error):
    real_id  = 6521

class AppStoreMissingDependenciesDetailedError(Error):
    real_id  = 6530

class AppStorePackageVerificationError(Error):
    real_id  = 6531

class AppStorePackageIntegrityError(Error):
    real_id  = 6532

class AppStoreRunningScriptError(Error):
    real_id  = 6533

class AppStoreWrongOsMinimalVersionError(Error):
    real_id  = 6534

class AppStoreWrongOsMaximalVersionError(Error):
    real_id  = 6535

class AppStoreWrongOsVersionError(Error):
    real_id  = 6536

class AppStoreProductCompatibilityError(Error):
    real_id  = 6537

class AppStoreProductArchitectureCompatibilityError(Error):
    real_id  = 6538

class UserNotAllowedForThisApplication(Error):
    real_id  = 6560

class SettingsFileReadError(Error):
    real_id  = 7001

class SettingsFileNoLongerExists(Error):
    real_id  = 7002

class SettingsFileUploadInProgress(Error):
    real_id  = 7003

class SettingsVolumeMappingError(Error):
    real_id  = 7004

class SettingsFileVersionError(Error):
    real_id  = 7005

class SettingsChecksumError(Error):
    real_id  = 7006

class SdriveUnExpectedError(Error):
    real_id  = 7500

class SdriveUserNotFound(Error):
    real_id  = 7501

class SdriveCertNotFound(Error):
    real_id  = 7502

class SdriveCouldNotGenerateCert(Error):
    real_id  = 7503

class SdriveUserEmailAlreadyExists(Error):
    real_id  = 7504

class SdrivePrivateKeyAlreadyStored(Error):
    real_id  = 7505

class SdrivePrivateKeyUpdated(Error):
    real_id  = 7506

class SdriveUserNotAuthenticated(Error):
    real_id  = 7507

class SdriveVersionsDontMatch(Error):
    real_id  = 7508

class SdriveErrorUpdatePrivateKey(Error):
    real_id  = 7509

class SdriveConfirmationCodeFail(Error):
    real_id  = 7510

class SdriveConfirmationCodeExpired(Error):
    real_id  = 7511

class SdriveKeysDontMatch(Error):
    real_id  = 7512

class SdriveMailSendFail(Error):
    real_id  = 7513

class SdriveUserAddOperationFailed(Error):
    real_id  = 7514

class SdriveUserAlreadyExists(Error):
    real_id  = 7515

class SdriveCertExpired(Error):
    real_id  = 7516

class SdriveInvalidSignature(Error):
    real_id  = 7517

class SdriveInvalidAccessKey(Error):
    real_id  = 7518

class SdriveUpdateCredentialsParametersNull(Error):
    real_id  = 7519

class SdriveUserNotConfirmed(Error):
    real_id  = 7520

class SdriveCertificateRevoked(Error):
    real_id  = 7521

class SdriveValidationFailed(Error):
    real_id  = 7522

class SdriveGenerateCertificateError(Error):
    real_id  = 7523

class SdriveGenerateAccessKeyError(Error):
    real_id  = 7524

class SdriveGenerateCipherKeyError(Error):
    real_id  = 7525

class SdriveReadCertificateFailed(Error):
    real_id  = 7526

class SdriveGetUserIdFromCertificateFailed(Error):
    real_id  = 7527

class SdrivePrivateKeyCipherFailed(Error):
    real_id  = 7528

class SdriveConnectionError(Error):
    real_id  = 7529

class SdriveConnectionTimeout(Error):
    real_id  = 7530

class SdriveBufferTooSmall(Error):
    real_id  = 7531

class SdriveHeaderIntegrityCheckFailed(Error):
    real_id  = 7532

class SdriveDataIntegrityCheckFailed(Error):
    real_id  = 7533

class SdriveSequenceMismatch(Error):
    real_id  = 7534

class SdriveRmiError(Error):
    real_id  = 7535

class SdriveMessageMismatch(Error):
    real_id  = 7536

class SdriveClientIsBusy(Error):
    real_id  = 7537

class SdriveTlvError(Error):
    real_id  = 7538

class SdriveCertificateError(Error):
    real_id  = 7539

class SdriveInvalidCertificate(Error):
    real_id  = 7540

class SdriveUnknonwnCertificate(Error):
    real_id  = 7541

class SdriveRevokedCertificate(Error):
    real_id  = 7542

class SdriveExpiredCertificate(Error):
    real_id  = 7543

class SdriveUnknownDevice(Error):
    real_id  = 7544

class SdriveInviteAlreadyExist(Error):
    real_id  = 7545

class SdriveInviteAlreadyAssociated(Error):
    real_id  = 7546

class SdriveCantAcceptTemporaryAccount(Error):
    real_id  = 7547

class SdriveCantAssociateTemporaryAccount(Error):
    real_id  = 7548

class SdriveLocalAccountAlreadyExist(Error):
    real_id  = 7549

class SdriveCreateLocalAccount(Error):
    real_id  = 7550

class SdriveInviteUserError(Error):
    real_id  = 7551

class SdriveInviteDeviceCertificateError(Error):
    real_id  = 7552

class SdriveInviteDevicePrivateKeyError(Error):
    real_id  = 7553

class SdriveInviteConnectionToAuthenticatedServerFailed(Error):
    real_id  = 7554

class SdriveInviteUserCertificateFailed(Error):
    real_id  = 7555

class SdriveInviteUserIdExtractionFailed(Error):
    real_id  = 7556

class SdriveInviteUserPublicKeyFailed(Error):
    real_id  = 7557

class SdriveInviteEncryptionError(Error):
    real_id  = 7558

class SdriveInviteNotFound(Error):
    real_id  = 7559

class SdriveCredentialsUpdateFailed(Error):
    real_id  = 7560

class SdriveMailInvalid(Error):
    real_id  = 7561

class SdriveMailIsDEA(Error):
    real_id  = 7562

class SdriveHttpDownloadNotAllowed(Error):
    real_id  = 7563

class OAuth2GenericError(Error):
    real_id  = 8011

class OAuth2ServerConnectionError(Error):
    real_id  = 8012

class OAuth2TokenGenerationError(Error):
    real_id  = 8013

class OAuth2InvalidToken(Error):
    real_id  = 8014

class OAuth2InvalidRefreshToken(Error):
    real_id  = 8015

class CaptchaUnknownUser(Error):
    real_id  = 8101

class WrongCaptcha(Error):
    real_id  = 8102

class CaptchaNoEmail(Error):
    real_id  = 8103

class CaptchaDomainError(Error):
    real_id  = 8104

class CaptchaSmtpError(Error):
    real_id  = 8105

class CaptchaWrongToken(Error):
    real_id  = 8106

class FileSharingInvalidPath(Error):
    real_id  = 8500

class FileSharingWrongAccess(Error):
    real_id  = 8501

class FileSharingUnknownToken(Error):
    real_id  = 8502

class FileSharingAlreadyExists(Error):
    real_id  = 8503

class FileSharingWrongPassword(Error):
    real_id  = 8504

class FileSharingInvalidType(Error):
    real_id  = 8505

class FileSharingUnknownUser(Error):
    real_id  = 8506

class FileSharingUnknownId(Error):
    real_id  = 8507

class FileSharingWeblinkSupport(Error):
    real_id  = 8508

class FileSharingSdriveLinkSupport(Error):
    real_id  = 8509

class DownloadInvalidAction(Error):
    real_id  = 9001

class DownloadUploadedFileNoLongerExists(Error):
    real_id  = 9002

class DownloadUploadInProgress(Error):
    real_id  = 9003

class DownloadAlreadyExist(Error):
    real_id  = 9004

class SchedulePowerDuplicateAction(Error):
    real_id  = 9101

class SchedulePowerInvalidAction(Error):
    real_id  = 9102

class UrlProxyServerNotReachable(Error):
    real_id  = 9201

class UrlProxyRequestError(Error):
    real_id  = 9202

class SchedulingError(Error):
    real_id  = 9301

class FolderInvalidUri(Error):
    real_id  = 9302

class FolderAuthenticationError(Error):
    real_id  = 9303

class FolderInvalidOptions(Error):
    real_id  = 9304

class FolderNoAccess(Error):
    real_id  = 9305

class FolderReadOnly(Error):
    real_id  = 9306

class FolderUnknownError(Error):
    real_id  = 9307

class InvalidJobName(Error):
    real_id  = 9308

class InvalidRestorePoint(Error):
    real_id  = 9309

class FolderHostNotReachable(Error):
    real_id  = 9310

class FolderIncompatibleServer(Error):
    real_id  = 9311

class FolderTimeout(Error):
    real_id  = 9312

class FolderNoSpaceLeft(Error):
    real_id  = 9313

class CertificateUploadedFileNoLongerExists(Error):
    real_id  = 9401

class CertificateUploadInProgress(Error):
    real_id  = 9402

class CertificateValidationError(Error):
    real_id  = 9403
error_table[0] = AuthenticationError
error_table[1] = TimeIsSkewedError
error_table[2] = WrongCredentialsError
error_table[3] = NotEnoughRights
error_table[4] = UnknownToken
error_table[5] = ElapsedToken
error_table[6] = UnknownApplicationToken
error_table[7] = ElapsedApplicationToken
error_table[4501] = PortMappingNotFound
error_table[2135] = NetBackupAlreadyCreated
error_table[2050] = PrinterNotFound
error_table[2136] = NetBackupNotCreated
error_table[2051] = CloudPrintCredentialsNotSet
error_table[20] = TooManyTokens
error_table[7001] = SettingsFileReadError
error_table[7002] = SettingsFileNoLongerExists
error_table[7003] = SettingsFileUploadInProgress
error_table[2138] = TimeMachineAlreadyActive
error_table[7004] = SettingsVolumeMappingError
error_table[7554] = SdriveInviteConnectionToAuthenticatedServerFailed
error_table[7537] = SdriveClientIsBusy
error_table[7503] = SdriveCouldNotGenerateCert
error_table[2100] = HostNotFound
error_table[2101] = ServiceNotFound
error_table[2102] = PortAlreadyInUse
error_table[7555] = SdriveInviteUserCertificateFailed
error_table[7538] = SdriveTlvError
error_table[2132] = RemoteBackupActivationUserAlreadyExists
error_table[9301] = SchedulingError
error_table[9302] = FolderInvalidUri
error_table[9303] = FolderAuthenticationError
error_table[9304] = FolderInvalidOptions
error_table[9305] = FolderNoAccess
error_table[9306] = FolderReadOnly
error_table[9307] = FolderUnknownError
error_table[9308] = InvalidJobName
error_table[9309] = InvalidRestorePoint
error_table[9310] = FolderHostNotReachable
error_table[9311] = FolderIncompatibleServer
error_table[9312] = FolderTimeout
error_table[9313] = FolderNoSpaceLeft
error_table[2150] = UpsDeviceNotFound
error_table[7539] = SdriveCertificateError
error_table[7502] = SdriveCertNotFound
error_table[4030] = ServiceByNicNotFound
error_table[8102] = WrongCaptcha
error_table[2033] = QuotaNotFound
error_table[7540] = SdriveInvalidCertificate
error_table[502] = WelcomeUserCreationFailed
error_table[7534] = SdriveSequenceMismatch
error_table[2200] = UnknownInvite
error_table[2201] = EmailAlreadyInvited
error_table[7535] = SdriveRmiError
error_table[7536] = SdriveMessageMismatch
error_table[7558] = SdriveInviteEncryptionError
error_table[6001] = BtsyncShareCreationFailed
error_table[4004] = InvalidHostname
error_table[6002] = BtsyncShareDeletionFailed
error_table[5001] = IscsiTargetNotFound
error_table[6003] = BtsyncShareNotFound
error_table[2137] = TimeMachineNotActive
error_table[6004] = BtsyncGenSecretFailed
error_table[9402] = CertificateUploadInProgress
error_table[9403] = CertificateValidationError
error_table[7541] = SdriveUnknonwnCertificate
error_table[7559] = SdriveInviteNotFound
error_table[7542] = SdriveRevokedCertificate
error_table[201] = MissingProperty
error_table[202] = BadPropertyType
error_table[203] = MalformedBody
error_table[204] = WrongFunctionPrototype
error_table[205] = UnexpectedProperty
error_table[5002] = IscsiTargetTotalCountExceeded
error_table[7544] = SdriveUnknownDevice
error_table[211] = WrongValue
error_table[212] = UnknownResource
error_table[7545] = SdriveInviteAlreadyExist
error_table[9401] = CertificateUploadedFileNoLongerExists
error_table[8101] = CaptchaUnknownUser
error_table[222] = NtpServerError
error_table[7560] = SdriveCredentialsUpdateFailed
error_table[7543] = SdriveExpiredCertificate
error_table[9202] = UrlProxyRequestError
error_table[7005] = SettingsFileVersionError
error_table[230] = FileSystemFileNotExists
error_table[2001] = QuotaNotAllowed
error_table[232] = FileSystemInvalidMove
error_table[233] = FileSystemErrorMove
error_table[7549] = SdriveLocalAccountAlreadyExist
error_table[2139] = TimeMachineAlreadyCreated
error_table[7550] = SdriveCreateLocalAccount
error_table[9201] = UrlProxyServerNotReachable
error_table[7551] = SdriveInviteUserError
error_table[7561] = SdriveMailInvalid
error_table[7552] = SdriveInviteDeviceCertificateError
error_table[7563] = SdriveHttpDownloadNotAllowed
error_table[7553] = SdriveInviteDevicePrivateKeyError
error_table[7006] = SettingsChecksumError
error_table[2134] = NetBackupAlreadyActive
error_table[6530] = AppStoreMissingDependenciesDetailedError
error_table[2140] = TimeMachineNotCreated
error_table[6531] = AppStorePackageVerificationError
error_table[7556] = SdriveInviteUserIdExtractionFailed
error_table[7562] = SdriveMailIsDEA
error_table[7557] = SdriveInviteUserPublicKeyFailed
error_table[503] = WelcomeShareCreationFailed
error_table[6534] = AppStoreWrongOsMinimalVersionError
error_table[9001] = DownloadInvalidAction
error_table[9002] = DownloadUploadedFileNoLongerExists
error_table[9003] = DownloadUploadInProgress
error_table[9004] = DownloadAlreadyExist
error_table[6536] = AppStoreWrongOsVersionError
error_table[8500] = FileSharingInvalidPath
error_table[8501] = FileSharingWrongAccess
error_table[8502] = FileSharingUnknownToken
error_table[8503] = FileSharingAlreadyExists
error_table[8504] = FileSharingWrongPassword
error_table[8505] = FileSharingInvalidType
error_table[8506] = FileSharingUnknownUser
error_table[8507] = FileSharingUnknownId
error_table[8508] = FileSharingWeblinkSupport
error_table[8509] = FileSharingSdriveLinkSupport
error_table[7500] = SdriveUnExpectedError
error_table[4000] = NetworkGenericError
error_table[8011] = OAuth2GenericError
error_table[8012] = OAuth2ServerConnectionError
error_table[8013] = OAuth2TokenGenerationError
error_table[8014] = OAuth2InvalidToken
error_table[8015] = OAuth2InvalidRefreshToken
error_table[7504] = SdriveUserEmailAlreadyExists
error_table[7505] = SdrivePrivateKeyAlreadyStored
error_table[7506] = SdrivePrivateKeyUpdated
error_table[7507] = SdriveUserNotAuthenticated
error_table[7508] = SdriveVersionsDontMatch
error_table[7509] = SdriveErrorUpdatePrivateKey
error_table[7510] = SdriveConfirmationCodeFail
error_table[7511] = SdriveConfirmationCodeExpired
error_table[7512] = SdriveKeysDontMatch
error_table[7513] = SdriveMailSendFail
error_table[7514] = SdriveUserAddOperationFailed
error_table[7515] = SdriveUserAlreadyExists
error_table[7516] = SdriveCertExpired
error_table[7517] = SdriveInvalidSignature
error_table[7518] = SdriveInvalidAccessKey
error_table[7519] = SdriveUpdateCredentialsParametersNull
error_table[7520] = SdriveUserNotConfirmed
error_table[7521] = SdriveCertificateRevoked
error_table[7522] = SdriveValidationFailed
error_table[7523] = SdriveGenerateCertificateError
error_table[7524] = SdriveGenerateAccessKeyError
error_table[7525] = SdriveGenerateCipherKeyError
error_table[7526] = SdriveReadCertificateFailed
error_table[7527] = SdriveGetUserIdFromCertificateFailed
error_table[7528] = SdrivePrivateKeyCipherFailed
error_table[7529] = SdriveConnectionError
error_table[7530] = SdriveConnectionTimeout
error_table[7531] = SdriveBufferTooSmall
error_table[7532] = SdriveHeaderIntegrityCheckFailed
error_table[7533] = SdriveDataIntegrityCheckFailed
error_table[6510] = AppStoreGenericError
error_table[6511] = AppStoreConnectionError
error_table[6512] = AppStoreMissingDependenciesError
error_table[6513] = AppStoreAppNotFoundError
error_table[6514] = AppStoreUpdateConflictingError
error_table[6515] = AppStoreDownloadError
error_table[6516] = AppStoreAppIsBrokenError
error_table[6517] = AppStoreRainbowGenericError
error_table[6518] = AppStorePortConflict1Error
error_table[6519] = AppStorePortConflict2Error
error_table[6520] = AppStorePortConflict3Error
error_table[6521] = AppStorePortConflictsError
error_table[7546] = SdriveInviteAlreadyAssociated
error_table[7547] = SdriveCantAcceptTemporaryAccount
error_table[7548] = SdriveCantAssociateTemporaryAccount
error_table[5501] = UnknownDevice
error_table[5502] = no_slots
error_table[5503] = no_free_space
error_table[5504] = slots_not_new
error_table[5505] = slots_already_used
error_table[5506] = not_enough_slots
error_table[5507] = partitionning_error
error_table[6532] = AppStorePackageIntegrityError
error_table[6533] = AppStoreRunningScriptError
error_table[5510] = raid_not_available
error_table[6535] = AppStoreWrongOsMaximalVersionError
error_table[5000] = IscsiUnExpectedError
error_table[6537] = AppStoreProductCompatibilityError
error_table[6538] = AppStoreProductArchitectureCompatibilityError
error_table[5003] = IscsiTargetLunCountExceeded
error_table[9101] = SchedulePowerDuplicateAction
error_table[9102] = SchedulePowerInvalidAction
error_table[5520] = no_encryption_password
error_table[5521] = RaidBadPassword
error_table[5522] = RaidBadMountpoint
error_table[5523] = RaidWriteError
error_table[5524] = RaidInvalidChar
error_table[5525] = RaidWaitUnlockError
error_table[5526] = RaidInvalidPasswordSize
error_table[5527] = InvalidProtectDir
error_table[231] = FileSystemFileAlreadyExists
error_table[6560] = UserNotAllowedForThisApplication
error_table[4001] = BackendGenericError
error_table[4002] = InterfaceDeleteForbidden
error_table[4003] = IDNotFound
error_table[5540] = UnknownPool
error_table[5541] = UnknownSlot
error_table[4006] = InvalidProxyConfig
error_table[4007] = InvalidBondingMode
error_table[4008] = InvalidIPMode
error_table[4009] = InvalidIPv4Address
error_table[4010] = InvalidMonitorInterval
error_table[4011] = InterfaceNotMaster
error_table[4012] = BondingNotEnoughSlaves
error_table[4013] = BondingPrimaryNotSlave
error_table[4014] = InterfaceConfigIncomplete
error_table[4015] = ReadOnlyAttribute
error_table[4016] = HostnameLocked
error_table[4017] = FriendlyNameAlreadyUsed
error_table[4018] = BondingInterfaceNotFound
error_table[4019] = InterfaceSlaveAlreadyUsed
error_table[4020] = CannotDisableAllInterfaces
error_table[4021] = InterfaceSlaveMissing
error_table[4022] = CannotDisablePrimaryInterface
error_table[4023] = InvalidIPv4Netmask
error_table[4024] = InvalidIPv6Address
error_table[3001] = BwAlreadyExists
error_table[3002] = BwDoesNotExists
error_table[5051] = IscsiLunNotFound
error_table[5052] = IscsiLunVolumeCountExceeded
error_table[5053] = IscsiLunFileNotEnoughSpace
error_table[5054] = IscsiLunFileExportFailed
error_table[5055] = IscsiLunFileImportFailed
error_table[5056] = IscsiLunFileDuplicateFailed
error_table[5057] = IscsiLunFileOpNotCanceled
error_table[5058] = IscsiLunFileSourceEmpty
error_table[5059] = IscsiLunFileOpInProgress
error_table[5060] = IscsiLunFileNoVolume
error_table[5061] = IscsiLunFileSourceNotExist
error_table[5062] = IscsiExternalVolumeError
error_table[5063] = IscsiVolumeDisabledError
error_table[5064] = IscsiLunFileDeleteError
error_table[5065] = IscsiLunFilePartition
error_table[5066] = IscsiLunFileAllocate
error_table[5067] = IscsiLunFileSparse
error_table[5068] = IscsiLunFileMaxSize
error_table[5069] = IscsiLunShrinkNotAllowed
error_table[5070] = IscsiLunBlockNoSize
error_table[5071] = IscsiIqnInvalidFormat
error_table[5072] = IscsiDuplicateIqn
error_table[5073] = IscsiIqnBadCase
error_table[5074] = IscsiLunBlockNoVolume
error_table[2005] = BrowsingInvalidPath
error_table[2006] = BrowsingWrongAccess
error_table[2007] = BrowsingUnknownToken
error_table[2008] = BrowsingAlreadyExists
error_table[2009] = BrowsingWrongPassword
error_table[2010] = ShareNotFound
error_table[2011] = ShareNameException
error_table[2012] = ShareNameAlreadyExists
error_table[2013] = ShareForbidenName
error_table[4005] = InvalidWorkgroup
error_table[2025] = DomainError
error_table[2020] = UserNotFound
error_table[2021] = UserNameException
error_table[2022] = UserNameAlreadyExists
error_table[2023] = UserForbidenName
error_table[2024] = WrongInputId
error_table[1001] = InvalidRequestConfig
error_table[1002] = UnicornSaveError
error_table[8103] = CaptchaNoEmail
error_table[5101] = IscsiLunInvalidType
error_table[2030] = GroupNotFound
error_table[2031] = GroupNameException
error_table[2032] = VolumeNotFound
error_table[8104] = CaptchaDomainError
error_table[2034] = GroupForbiddenName
error_table[2035] = MaxUserCountReached
error_table[2036] = MaxShareCountReached
error_table[501] = WelcomeAlreadyDone
error_table[7501] = SdriveUserNotFound
error_table[8105] = CaptchaSmtpError
error_table[504] = WelcomeUserNotFound
error_table[8106] = CaptchaWrongToken
error_table[2133] = NetBackupNotActive
