#!/usr/bin/python
# -*- coding: utf-8 -*-

#                         LACIE CONFIDENTIAL
#
# The information contained in this file is the property of LACIE.
# The user of this file shall keep information contained herein confidential
# and shall protect it in whole or in part from disclosure and dissemination
# to third parties.
# Without prior written consent of LACIE, you may not reproduce, represent,
# or download through any means, the information contained herein in any way
# or in any form for a purpose other that the use for internal evaluation,
# operation or maintenance within LACIE.
#
#          (c) LACIE, 2009 - 2012, All Rights Reserved.

#GEN_DATE Apr 30 2015 11:23:46
#
# 888b. .d88b.    8b  8 .d88b. 88888    8888 888b. 888 88888
# 8   8 8P  Y8    8Ybm8 8P  Y8   8      8www 8   8  8    8
# 8   8 8b  d8    8  '8 8b  d8   8      8    8   8  8    8
# 888P' `Y88P'    8   8 `Y88P'   8      8888 888P' 888   8
#
#

import time
from transformer.lib import Optional
from unicorn_api.v6.sv0.settings_backup.SettingsBackupLink import SettingsBackupLink
from unicorn_api.v6.sv0.settings_backup.SettingsBackupFileInfo import SettingsBackupFileInfo
from unicorn_api.v6.sv0.settings_backup.RestoreSelection import RestoreSelection

from transformer.lib import List, Dict

from transformer.client_serializer import ClientSerializer
from transformer.lib.client import APIService


class SettingsBackupAdministration(APIService):


    def backup(self, async_client_ref, setting_names, __client__=None, timeout=None, raw_output=False):
        """
        ############### restore settings to NAS ################
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['setting_names'] = setting_names
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.backup"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def backup_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.backup_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['download_link']



    def backup_wait(self, async_client_ref, setting_names, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        """
        ############### restore settings to NAS ################
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['setting_names'] = setting_names
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.backup"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.backup_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def list(self, __client__=None, timeout=None, raw_output=False):
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.list"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['setting_names']

    def list_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.list"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def read(self, token, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['token'] = token
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.read"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['result']

    def read_async(self, token, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['token'] = token
        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.read"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def restore(self, async_client_ref, token, selections, new_volume_mappings, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['token'] = token
        params['selections'] = selections
        params['new_volume_mappings'] = new_volume_mappings
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.restore"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def restore_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.restore_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['restored']



    def restore_wait(self, async_client_ref, token, selections, new_volume_mappings, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['token'] = token
        params['selections'] = selections
        params['new_volume_mappings'] = new_volume_mappings
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.restore"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.restore_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def set_file(self, filename, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['filename'] = filename
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.set_file"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['token']

    def set_file_async(self, filename, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['filename'] = filename
        url = "api/external/6.0/settings_backup.SettingsBackupAdministration.set_file"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)
