#!/usr/bin/python
# -*- coding: utf-8 -*-

#                         LACIE CONFIDENTIAL
#
# The information contained in this file is the property of LACIE.
# The user of this file shall keep information contained herein confidential
# and shall protect it in whole or in part from disclosure and dissemination
# to third parties.
# Without prior written consent of LACIE, you may not reproduce, represent,
# or download through any means, the information contained herein in any way
# or in any form for a purpose other that the use for internal evaluation,
# operation or maintenance within LACIE.
#
#          (c) LACIE, 2009 - 2012, All Rights Reserved.

#GEN_DATE Jan 18 2016 15:24:02
#
# 888b. .d88b.    8b  8 .d88b. 88888    8888 888b. 888 88888
# 8   8 8P  Y8    8Ybm8 8P  Y8   8      8www 8   8  8    8
# 8   8 8b  d8    8  '8 8b  d8   8      8    8   8  8    8
# 888P' `Y88P'    8   8 `Y88P'   8      8888 888P' 888   8
#
#

import time
from transformer.lib import Optional
from unicorn_api.v7.sv0.backup.Job import Job
from unicorn_api.v7.sv0.backup import JobKind
from unicorn_api.v7.sv0.backup import JobType
from unicorn_api.v7.sv0.backup.RestoreOptions import RestoreOptions
from unicorn_api.v7.sv0.backup.Folder import Folder
from unicorn_api.v7.sv0.backup.JobProgress import JobProgress
from unicorn_api.v7.sv0.backup.Scheduler import Scheduler
from unicorn_api.v7.sv0.backup.AuthenticationConfig import AuthenticationConfig
from unicorn_api.v7.sv0.backup.FolderOptions import FolderOptions
from unicorn_api.v7.sv0.backup.JobHistoryEntry import JobHistoryEntry

from transformer.lib import List, ListInfo, ResultSet, Date

from transformer.client_serializer import ClientSerializer
from transformer.lib.client import APIService


class BackupAdministration(APIService):


    def can_restore_in_place(self, backup_folder, unique_id, options, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['backup_folder'] = backup_folder
        params['unique_id'] = unique_id
        params['options'] = options
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.can_restore_in_place"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['allowed']

    def can_restore_in_place_async(self, backup_folder, unique_id, options, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['backup_folder'] = backup_folder
        params['unique_id'] = unique_id
        params['options'] = options
        url = "api/external/7.0/backup.BackupAdministration.can_restore_in_place"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def can_restore_in_place_from_job(self, job_id, unique_id, options, __client__=None, timeout=None, raw_output=False):
        """
         Checks if a backup job destination can be restored at the backup
         source.
        
         This works only if the backup job has a single destination,
         otherwise use can_restore_in_place on each backup destination
         folder.
        """
        params = dict()
        params['job_id'] = job_id
        params['unique_id'] = unique_id
        params['options'] = options
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.can_restore_in_place_from_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['allowed']

    def can_restore_in_place_from_job_async(self, job_id, unique_id, options, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        params['unique_id'] = unique_id
        params['options'] = options
        url = "api/external/7.0/backup.BackupAdministration.can_restore_in_place_from_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def clear_job_history(self, job_id, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['job_id'] = job_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.clear_job_history"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 

    def clear_job_history_async(self, job_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        url = "api/external/7.0/backup.BackupAdministration.clear_job_history"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def create_job(self, job, __client__=None, timeout=None, raw_output=False):
        """
         Create a new backup or sync job
        """
        params = dict()
        params['job'] = job
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.create_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def create_job_async(self, job, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job'] = job
        url = "api/external/7.0/backup.BackupAdministration.create_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def create_restore_job_from_backup_folder(self, backup_folder, backup_history_id, name, description, options, __client__=None, timeout=None, raw_output=False):
        """
         Create a new restore job, based on backup metadata stored in the backup directory
        """
        params = dict()
        params['backup_folder'] = backup_folder
        params['backup_history_id'] = backup_history_id
        params['name'] = name
        params['description'] = description
        params['options'] = options
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.create_restore_job_from_backup_folder"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def create_restore_job_from_backup_folder_async(self, backup_folder, backup_history_id, name, description, options, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['backup_folder'] = backup_folder
        params['backup_history_id'] = backup_history_id
        params['name'] = name
        params['description'] = description
        params['options'] = options
        url = "api/external/7.0/backup.BackupAdministration.create_restore_job_from_backup_folder"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def create_restore_job_from_backup_job(self, backup_job_id, backup_history_id, name, description, options, __client__=None, timeout=None, raw_output=False):
        """
         Create a new restore job, based on an existing backup job
        """
        params = dict()
        params['backup_job_id'] = backup_job_id
        params['backup_history_id'] = backup_history_id
        params['name'] = name
        params['description'] = description
        params['options'] = options
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.create_restore_job_from_backup_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def create_restore_job_from_backup_job_async(self, backup_job_id, backup_history_id, name, description, options, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['backup_job_id'] = backup_job_id
        params['backup_history_id'] = backup_history_id
        params['name'] = name
        params['description'] = description
        params['options'] = options
        url = "api/external/7.0/backup.BackupAdministration.create_restore_job_from_backup_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def delete_job(self, job_id, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['job_id'] = job_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.delete_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 

    def delete_job_async(self, job_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        url = "api/external/7.0/backup.BackupAdministration.delete_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def enable_job(self, job_id, enable, __client__=None, timeout=None, raw_output=False):
        """
         Enables/disables a job
        """
        params = dict()
        params['job_id'] = job_id
        params['enable'] = enable
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.enable_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def enable_job_async(self, job_id, enable, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        params['enable'] = enable
        url = "api/external/7.0/backup.BackupAdministration.enable_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def folder_supports_incremental_backup(self, folder, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['folder'] = folder
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.folder_supports_incremental_backup"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['supported']

    def folder_supports_incremental_backup_async(self, folder, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['folder'] = folder
        url = "api/external/7.0/backup.BackupAdministration.folder_supports_incremental_backup"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_folder_history(self, folder, list_info, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['folder'] = folder
        params['list_info'] = list_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.get_folder_history"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['history']

    def get_folder_history_async(self, folder, list_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['folder'] = folder
        params['list_info'] = list_info
        url = "api/external/7.0/backup.BackupAdministration.get_folder_history"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_folder_history_from_job(self, job_id, list_info, __client__=None, timeout=None, raw_output=False):
        """
         Retrieves the history of a job's destination folder.
        
         This works only if the destination is unique, otherwise use
         get_folder_history on each destination folder.
        """
        params = dict()
        params['job_id'] = job_id
        params['list_info'] = list_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.get_folder_history_from_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['history']

    def get_folder_history_from_job_async(self, job_id, list_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        params['list_info'] = list_info
        url = "api/external/7.0/backup.BackupAdministration.get_folder_history_from_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_job(self, with_parameters, job_id, __client__=None, timeout=None, raw_output=False):
        """
         Retrieve a job info by id.
         You can only get backups that belongs to you, or any if you are an admin
        """
        params = dict()
        params['with_parameters'] = with_parameters
        params['job_id'] = job_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.get_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def get_job_async(self, with_parameters, job_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['with_parameters'] = with_parameters
        params['job_id'] = job_id
        url = "api/external/7.0/backup.BackupAdministration.get_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_job_from_folder(self, folder, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['folder'] = folder
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.get_job_from_folder"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def get_job_from_folder_async(self, folder, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['folder'] = folder
        url = "api/external/7.0/backup.BackupAdministration.get_job_from_folder"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_job_history(self, job_id, list_info, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['job_id'] = job_id
        params['list_info'] = list_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.get_job_history"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['history']

    def get_job_history_async(self, job_id, list_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        params['list_info'] = list_info
        url = "api/external/7.0/backup.BackupAdministration.get_job_history"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_job_progress(self, job_id, __client__=None, timeout=None, raw_output=False):
        """
         Retrieve a job progress by id.
        """
        params = dict()
        params['job_id'] = job_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.get_job_progress"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['progress']

    def get_job_progress_async(self, job_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        url = "api/external/7.0/backup.BackupAdministration.get_job_progress"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_max_jobs(self, __client__=None, timeout=None, raw_output=False):
        """
         Get maximum of parallel jobs
        """
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.get_max_jobs"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['maximum']

    def get_max_jobs_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/7.0/backup.BackupAdministration.get_max_jobs"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list_dirs(self, folder, __client__=None, timeout=None, raw_output=False):
        """
         Lists the directories inside given folder (for browsing)
         TODO: Maybe whe should make it asynchronous in case the user has
         an awful lot of dirs in that folder
                function list_job_conflicts:
                    in: - Integer job_id
                    out: - List<Unicode> conflicts
                    errors: void
        """
        params = dict()
        params['folder'] = folder
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.list_dirs"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['dirs']

    def list_dirs_async(self, folder, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['folder'] = folder
        url = "api/external/7.0/backup.BackupAdministration.list_dirs"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list_filesystems_supporting_incremental_backup(self, __client__=None, timeout=None, raw_output=False):
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.list_filesystems_supporting_incremental_backup"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['supported']

    def list_filesystems_supporting_incremental_backup_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/7.0/backup.BackupAdministration.list_filesystems_supporting_incremental_backup"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list_jobs(self, with_parameters, list_info, __client__=None, timeout=None, raw_output=False):
        """
         Lists jobs and filters
        """
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.list_jobs"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['jobs']

    def list_jobs_async(self, with_parameters, list_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        url = "api/external/7.0/backup.BackupAdministration.list_jobs"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list_modules(self, folder, __client__=None, timeout=None, raw_output=False):
        """
         Lists the shared directories inside given folder
        """
        params = dict()
        params['folder'] = folder
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.list_modules"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['dirs']

    def list_modules_async(self, folder, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['folder'] = folder
        url = "api/external/7.0/backup.BackupAdministration.list_modules"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def myJobs(self, with_parameters, list_info, __client__=None, timeout=None, raw_output=False):
        """
         Lists jobs and filters
        """
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.myJobs"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['jobs']

    def myJobs_async(self, with_parameters, list_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        url = "api/external/7.0/backup.BackupAdministration.myJobs"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def schedule_job(self, job_id, scheduler, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['job_id'] = job_id
        params['scheduler'] = scheduler
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.schedule_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def schedule_job_async(self, job_id, scheduler, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        params['scheduler'] = scheduler
        url = "api/external/7.0/backup.BackupAdministration.schedule_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def set_folder_auth(self, folder_id, auth_info, __client__=None, timeout=None, raw_output=False):
        """
         Update authentication properties of a given folder
        """
        params = dict()
        params['folder_id'] = folder_id
        params['auth_info'] = auth_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.set_folder_auth"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['folder']

    def set_folder_auth_async(self, folder_id, auth_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['folder_id'] = folder_id
        params['auth_info'] = auth_info
        url = "api/external/7.0/backup.BackupAdministration.set_folder_auth"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def set_folder_options(self, folder_id, options, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['folder_id'] = folder_id
        params['options'] = options
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.set_folder_options"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['folder']

    def set_folder_options_async(self, folder_id, options, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['folder_id'] = folder_id
        params['options'] = options
        url = "api/external/7.0/backup.BackupAdministration.set_folder_options"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def set_folder_uri(self, folder_id, uri, unique_sub_path, __client__=None, timeout=None, raw_output=False):
        """
         Update the uri, and optionally the unique subpath of a given folder
        """
        params = dict()
        params['folder_id'] = folder_id
        params['uri'] = uri
        params['unique_sub_path'] = unique_sub_path
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.set_folder_uri"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['folder']

    def set_folder_uri_async(self, folder_id, uri, unique_sub_path, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['folder_id'] = folder_id
        params['uri'] = uri
        params['unique_sub_path'] = unique_sub_path
        url = "api/external/7.0/backup.BackupAdministration.set_folder_uri"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def set_job_description(self, job_id, description, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['job_id'] = job_id
        params['description'] = description
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.set_job_description"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def set_job_description_async(self, job_id, description, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        params['description'] = description
        url = "api/external/7.0/backup.BackupAdministration.set_job_description"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def set_max_jobs(self, maximum, __client__=None, timeout=None, raw_output=False):
        """
         Set maximum of parallel jobs
        """
        params = dict()
        params['maximum'] = maximum
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.set_max_jobs"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['maximum']

    def set_max_jobs_async(self, maximum, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['maximum'] = maximum
        url = "api/external/7.0/backup.BackupAdministration.set_max_jobs"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def start_job(self, job_id, __client__=None, timeout=None, raw_output=False):
        """
         Starts a job
        """
        params = dict()
        params['job_id'] = job_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.start_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def start_job_async(self, job_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        url = "api/external/7.0/backup.BackupAdministration.start_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def stop_job(self, job_id, __client__=None, timeout=None, raw_output=False):
        """
         Stops a job
        """
        params = dict()
        params['job_id'] = job_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.stop_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def stop_job_async(self, job_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        url = "api/external/7.0/backup.BackupAdministration.stop_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def test_job_folders(self, async_client_ref, job, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['job'] = job
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.test_job_folders"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def test_job_folders_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/backup.BackupAdministration.test_job_folders_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def test_job_folders_wait(self, async_client_ref, job, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['job'] = job
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.test_job_folders"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.test_job_folders_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def unschedule_job(self, job_id, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['job_id'] = job_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.unschedule_job"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['job']

    def unschedule_job_async(self, job_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['job_id'] = job_id
        url = "api/external/7.0/backup.BackupAdministration.unschedule_job"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def uri_supports_incremental_backup(self, uri, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['uri'] = uri
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/backup.BackupAdministration.uri_supports_incremental_backup"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['supported']

    def uri_supports_incremental_backup_async(self, uri, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['uri'] = uri
        url = "api/external/7.0/backup.BackupAdministration.uri_supports_incremental_backup"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)
