#!/usr/bin/python
# -*- coding: utf-8 -*-

#                         LACIE CONFIDENTIAL
#
# The information contained in this file is the property of LACIE.
# The user of this file shall keep information contained herein confidential
# and shall protect it in whole or in part from disclosure and dissemination
# to third parties.
# Without prior written consent of LACIE, you may not reproduce, represent,
# or download through any means, the information contained herein in any way
# or in any form for a purpose other that the use for internal evaluation,
# operation or maintenance within LACIE.
#
#          (c) LACIE, 2009 - 2012, All Rights Reserved.

#GEN_DATE Jan 18 2016 15:24:02
#
# 888b. .d88b.    8b  8 .d88b. 88888    8888 888b. 888 88888
# 8   8 8P  Y8    8Ybm8 8P  Y8   8      8www 8   8  8    8
# 8   8 8b  d8    8  '8 8b  d8   8      8    8   8  8    8
# 888P' `Y88P'    8   8 `Y88P'   8      8888 888P' 888   8
#
#

import time
from transformer.lib import Optional
from unicorn_api.v7.sv0.btsync.BtsyncConf import BtsyncConf
from unicorn_api.v7.sv0.btsync.BtsyncShare import BtsyncShare

from transformer.lib import List, ListInfo, ResultSet

from transformer.client_serializer import ClientSerializer
from transformer.lib.client import APIService


class BtsyncAdministration(APIService):


    def enable_btsync(self, share_id, enable, __client__=None, timeout=None, raw_output=False):
        """
         Enable/disable btsync on share. Create btsync share configuration if none exist
        """
        params = dict()
        params['share_id'] = share_id
        params['enable'] = enable
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.enable_btsync"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['btsync_share_conf']

    def enable_btsync_async(self, share_id, enable, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['share_id'] = share_id
        params['enable'] = enable
        url = "api/external/7.0/btsync.BtsyncAdministration.enable_btsync"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def generate_secret(self, share_id, __client__=None, timeout=None, raw_output=False):
        """
         Generate secret key on a share and update its btsync conf with this new value
        """
        params = dict()
        params['share_id'] = share_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.generate_secret"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['btsync_share_conf']

    def generate_secret_async(self, share_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['share_id'] = share_id
        url = "api/external/7.0/btsync.BtsyncAdministration.generate_secret"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_config(self, __client__=None, timeout=None, raw_output=False):
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.get_config"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['conf']

    def get_config_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/7.0/btsync.BtsyncAdministration.get_config"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list(self, with_parameters, list_info, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.list"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['btsync_share_confs']

    def list_async(self, with_parameters, list_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        url = "api/external/7.0/btsync.BtsyncAdministration.list"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def remove_btsync(self, share_id, __client__=None, timeout=None, raw_output=False):
        """
         Remove btsync from a share
        """
        params = dict()
        params['share_id'] = share_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.remove_btsync"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 

    def remove_btsync_async(self, share_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['share_id'] = share_id
        url = "api/external/7.0/btsync.BtsyncAdministration.remove_btsync"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def set_download_limit(self, dl_value, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['dl_value'] = dl_value
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.set_download_limit"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['conf']

    def set_download_limit_async(self, dl_value, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['dl_value'] = dl_value
        url = "api/external/7.0/btsync.BtsyncAdministration.set_download_limit"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def set_enabled(self, enabled, __client__=None, timeout=None, raw_output=False):
        """
         Enable/Disable btsync service
        """
        params = dict()
        params['enabled'] = enabled
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.set_enabled"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['conf']

    def set_enabled_async(self, enabled, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['enabled'] = enabled
        url = "api/external/7.0/btsync.BtsyncAdministration.set_enabled"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def set_upload_limit(self, ul_value, __client__=None, timeout=None, raw_output=False):
        """
        #################### config by share ####################
        """
        params = dict()
        params['ul_value'] = ul_value
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.set_upload_limit"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['conf']

    def set_upload_limit_async(self, ul_value, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['ul_value'] = ul_value
        url = "api/external/7.0/btsync.BtsyncAdministration.set_upload_limit"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def set_use_upnp(self, enabled, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['enabled'] = enabled
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.set_use_upnp"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['conf']

    def set_use_upnp_async(self, enabled, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['enabled'] = enabled
        url = "api/external/7.0/btsync.BtsyncAdministration.set_use_upnp"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def update_btsync(self, share_id, new_btsync_share_conf, __client__=None, timeout=None, raw_output=False):
        """
         Update btsync conf on a share
         ( secret, use_relay_server, use_tracker, use_dht, search_lan, use_sync_trash )
        """
        params = dict()
        params['share_id'] = share_id
        params['new_btsync_share_conf'] = new_btsync_share_conf
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/btsync.BtsyncAdministration.update_btsync"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['btsync_share_conf']

    def update_btsync_async(self, share_id, new_btsync_share_conf, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['share_id'] = share_id
        params['new_btsync_share_conf'] = new_btsync_share_conf
        url = "api/external/7.0/btsync.BtsyncAdministration.update_btsync"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)
