#!/usr/bin/python
# -*- coding: utf-8 -*-

#                         LACIE CONFIDENTIAL
#
# The information contained in this file is the property of LACIE.
# The user of this file shall keep information contained herein confidential
# and shall protect it in whole or in part from disclosure and dissemination
# to third parties.
# Without prior written consent of LACIE, you may not reproduce, represent,
# or download through any means, the information contained herein in any way
# or in any form for a purpose other that the use for internal evaluation,
# operation or maintenance within LACIE.
#
#          (c) LACIE, 2009 - 2012, All Rights Reserved.

#GEN_DATE Jan 18 2016 15:24:02
#
# 888b. .d88b.    8b  8 .d88b. 88888    8888 888b. 888 88888
# 8   8 8P  Y8    8Ybm8 8P  Y8   8      8www 8   8  8    8
# 8   8 8b  d8    8  '8 8b  d8   8      8    8   8  8    8
# 888P' `Y88P'    8   8 `Y88P'   8      8888 888P' 888   8
#
#

import time
from transformer.lib import Optional
from unicorn_api.v7.sv0.iscsi_multi_lun.Lun import Lun
from unicorn_api.v7.sv0.iscsi_multi_lun import LunStatus

from transformer.lib import Long, ListInfo, ResultSet, List

from transformer.client_serializer import ClientSerializer
from transformer.lib.client import APIService


class LunAdministration(APIService):


    def _get_lun_count(self, __client__=None, timeout=None, raw_output=False):
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/local/7.0/iscsi_multi_lun.LunAdministration._get_lun_count"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['count']

    def _get_lun_count_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/local/7.0/iscsi_multi_lun.LunAdministration._get_lun_count"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def cancel_duplicate(self, lun_id, __client__=None, timeout=None, raw_output=False):
        """
         To cancel an iSCSI Lun duplication
         -------------------   TARGET/LUN  OPERATIONS  ---------------------#
        useless? #TODO TEST
        """
        params = dict()
        params['lun_id'] = lun_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.cancel_duplicate"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['canceled_lun']

    def cancel_duplicate_async(self, lun_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['lun_id'] = lun_id
        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.cancel_duplicate"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def cancel_export(self, lun_id, __client__=None, timeout=None, raw_output=False):
        """
         To cancel an iSCSI Lun export
        """
        params = dict()
        params['lun_id'] = lun_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.cancel_export"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['canceled_lun']

    def cancel_export_async(self, lun_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['lun_id'] = lun_id
        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.cancel_export"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def cancel_import(self, lun_id, __client__=None, timeout=None, raw_output=False):
        """
         To cancel an iSCSI Lun import
        """
        params = dict()
        params['lun_id'] = lun_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.cancel_import"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['lun_canceled']

    def cancel_import_async(self, lun_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['lun_id'] = lun_id
        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.cancel_import"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def create(self, async_client_ref, lun_settings, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['lun_settings'] = lun_settings
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.create"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def create_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.create_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['new_lun']



    def create_wait(self, async_client_ref, lun_settings, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['lun_settings'] = lun_settings
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.create"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.create_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def delete(self, async_client_ref, lun_id, __client__=None, timeout=None, raw_output=False):
        """
         To delete a lun
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['lun_id'] = lun_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.delete"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def delete_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.delete_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def delete_wait(self, async_client_ref, lun_id, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        """
         To delete a lun
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['lun_id'] = lun_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.delete"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.delete_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def duplicate_lun(self, async_client_ref, lun_src_id, lun_settings, __client__=None, timeout=None, raw_output=False):
        """
         To duplicate an iSCSI Lun
         lun_src_id is referring to the the LUN source to copy from
         lun_settings is the duplicated LUN settings
        TODO TEST
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['lun_src_id'] = lun_src_id
        params['lun_settings'] = lun_settings
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.duplicate_lun"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def duplicate_lun_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.duplicate_lun_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['cloned_lun']



    def duplicate_lun_wait(self, async_client_ref, lun_src_id, lun_settings, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        """
         To duplicate an iSCSI Lun
         lun_src_id is referring to the the LUN source to copy from
         lun_settings is the duplicated LUN settings
        TODO TEST
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['lun_src_id'] = lun_src_id
        params['lun_settings'] = lun_settings
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.duplicate_lun"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.duplicate_lun_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def edit(self, lun_settings, __client__=None, timeout=None, raw_output=False):
        """
         --- ADVANCED LUN OPERATIONS : import, export, duplicate, cancel ---#
        """
        params = dict()
        params['lun_settings'] = lun_settings
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.edit"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['updated_lun']

    def edit_async(self, lun_settings, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['lun_settings'] = lun_settings
        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.edit"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def export_to_share(self, async_client_ref, lun_src_id, dest_share_path, __client__=None, timeout=None, raw_output=False):
        """
         To export an iSCSI Lun to a share
        TODO TEST
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['lun_src_id'] = lun_src_id
        params['dest_share_path'] = dest_share_path
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.export_to_share"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def export_to_share_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.export_to_share_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def export_to_share_wait(self, async_client_ref, lun_src_id, dest_share_path, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        """
         To export an iSCSI Lun to a share
        TODO TEST
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['lun_src_id'] = lun_src_id
        params['dest_share_path'] = dest_share_path
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.export_to_share"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.export_to_share_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def import_from_share(self, async_client_ref, src_share_path, lun_settings, __client__=None, timeout=None, raw_output=False):
        """
         To import an existing iSCSI Lun date file from a share and put it
         in the LUNs store.
         dest_volume_id : cannot import if max_volume_lun_count exceed
         --- TODO TEST
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['src_share_path'] = src_share_path
        params['lun_settings'] = lun_settings
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.import_from_share"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def import_from_share_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.import_from_share_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['new_lun']



    def import_from_share_wait(self, async_client_ref, src_share_path, lun_settings, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        """
         To import an existing iSCSI Lun date file from a share and put it
         in the LUNs store.
         dest_volume_id : cannot import if max_volume_lun_count exceed
         --- TODO TEST
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['src_share_path'] = src_share_path
        params['lun_settings'] = lun_settings
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.import_from_share"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.import_from_share_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def list(self, list_info, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['list_info'] = list_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.list"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['luns']

    def list_async(self, list_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['list_info'] = list_info
        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.list"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def map_target(self, lun_id, target_ids, add_mode, __client__=None, timeout=None, raw_output=False):
        """
         Map target(s) to a lun
        """
        params = dict()
        params['lun_id'] = lun_id
        params['target_ids'] = target_ids
        params['add_mode'] = add_mode
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.map_target"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['updated_lun']

    def map_target_async(self, lun_id, target_ids, add_mode, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['lun_id'] = lun_id
        params['target_ids'] = target_ids
        params['add_mode'] = add_mode
        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.map_target"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def max_lun_size(self, __client__=None, timeout=None, raw_output=False):
        """
        maximum size of IscsiLun lun file
        """
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.max_lun_size"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['value']

    def max_lun_size_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.max_lun_size"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def max_volume_lun_count(self, __client__=None, timeout=None, raw_output=False):
        """
        maximum number of allowed IscsiLun per volume (0 = no limit)
        """
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.max_volume_lun_count"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['value']

    def max_volume_lun_count_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/7.0/iscsi_multi_lun.LunAdministration.max_volume_lun_count"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)
