#!/usr/bin/python
# -*- coding: utf-8 -*-

#                         LACIE CONFIDENTIAL
#
# The information contained in this file is the property of LACIE.
# The user of this file shall keep information contained herein confidential
# and shall protect it in whole or in part from disclosure and dissemination
# to third parties.
# Without prior written consent of LACIE, you may not reproduce, represent,
# or download through any means, the information contained herein in any way
# or in any form for a purpose other that the use for internal evaluation,
# operation or maintenance within LACIE.
#
#          (c) LACIE, 2009 - 2012, All Rights Reserved.

#GEN_DATE Jan 18 2016 15:24:02
#
# 888b. .d88b.    8b  8 .d88b. 88888    8888 888b. 888 88888
# 8   8 8P  Y8    8Ybm8 8P  Y8   8      8www 8   8  8    8
# 8   8 8b  d8    8  '8 8b  d8   8      8    8   8  8    8
# 888P' `Y88P'    8   8 `Y88P'   8      8888 888P' 888   8
#
#

import time
from transformer.lib import Optional
from unicorn_api.v7.sv0.network_security.CertificateInfo import CertificateInfo

from transformer.client_serializer import ClientSerializer
from transformer.lib.client import APIService


class CertificateAdministration(APIService):


    def get_certificate_infos(self, __client__=None, timeout=None, raw_output=False):
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/network_security.CertificateAdministration.get_certificate_infos"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['infos']

    def get_certificate_infos_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/7.0/network_security.CertificateAdministration.get_certificate_infos"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def init_upload(self, filename, __client__=None, timeout=None, raw_output=False):
        """
         Use this method to upload a file (certificate and/or private key) to Nas
        """
        params = dict()
        params['filename'] = filename
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/network_security.CertificateAdministration.init_upload"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['token']

    def init_upload_async(self, filename, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['filename'] = filename
        url = "api/external/7.0/network_security.CertificateAdministration.init_upload"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def install(self, crt_or_bundle_token, prv_key_token, __client__=None, timeout=None, raw_output=False):
        """
         Install certificate and private key
         - crt_or_bundle_token: the certificate or bundle (crt + prv key)'s token uploaded
         - prv_key_token: the private key's token uploaded. set to empty '' if
            it wasn't uploaded or if is stored in the bundle.
                function generate:
                    in: void
                    out: void
                    errors: void
                function export:
                    in: void
                    out: void
                    errors: void
        """
        params = dict()
        params['crt_or_bundle_token'] = crt_or_bundle_token
        params['prv_key_token'] = prv_key_token
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/network_security.CertificateAdministration.install"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['installed']

    def install_async(self, crt_or_bundle_token, prv_key_token, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['crt_or_bundle_token'] = crt_or_bundle_token
        params['prv_key_token'] = prv_key_token
        url = "api/external/7.0/network_security.CertificateAdministration.install"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def reset(self, __client__=None, timeout=None, raw_output=False):
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/network_security.CertificateAdministration.reset"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 

    def reset_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/7.0/network_security.CertificateAdministration.reset"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)
