#!/usr/bin/python
# -*- coding: utf-8 -*-

#                         LACIE CONFIDENTIAL
#
# The information contained in this file is the property of LACIE.
# The user of this file shall keep information contained herein confidential
# and shall protect it in whole or in part from disclosure and dissemination
# to third parties.
# Without prior written consent of LACIE, you may not reproduce, represent,
# or download through any means, the information contained herein in any way
# or in any form for a purpose other that the use for internal evaluation,
# operation or maintenance within LACIE.
#
#          (c) LACIE, 2009 - 2012, All Rights Reserved.

#GEN_DATE Jan 18 2016 15:24:02
#
# 888b. .d88b.    8b  8 .d88b. 88888    8888 888b. 888 88888
# 8   8 8P  Y8    8Ybm8 8P  Y8   8      8www 8   8  8    8
# 8   8 8b  d8    8  '8 8b  d8   8      8    8   8  8    8
# 888P' `Y88P'    8   8 `Y88P'   8      8888 888P' 888   8
#
#

import time
from transformer.lib import Optional
from unicorn_api.v7.sv0.raid.Pool import Pool
from unicorn_api.v7.sv0.raid.Slot import Slot
from unicorn_api.v7.sv0.raid.RaidLevelInfo import RaidLevelInfo
from unicorn_api.v7.sv0.raid import RaidMode
from unicorn_api.v7.sv0.raid import RaidLevel
from unicorn_api.v7.sv0.raid import RedundancyLevel
from unicorn_api.v7.sv0.raid import LvManagement
from unicorn_api.v7.sv0.raid.LevelInfo import LevelInfo
from unicorn_api.v7.sv0.raid.MigrationStatusInfo import MigrationStatusInfo
from unicorn_api.v7.sv0.raid.AnyRaidSizeInfo import AnyRaidSizeInfo
from unicorn_api.v7.sv0.raid.SlotInError import SlotInError

from transformer.lib import List

from transformer.client_serializer import ClientSerializer
from transformer.lib.client import APIService


class RaidManagement(APIService):


    def add_slots(self, async_client_ref, pool_name, slot_indexes, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['slot_indexes'] = slot_indexes
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.add_slots"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def add_slots_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/raid.RaidManagement.add_slots_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def add_slots_wait(self, async_client_ref, pool_name, slot_indexes, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['slot_indexes'] = slot_indexes
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.add_slots"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.add_slots_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def add_spares(self, async_client_ref, pool_name, slots_indexes, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['slots_indexes'] = slots_indexes
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.add_spares"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def add_spares_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/raid.RaidManagement.add_spares_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def add_spares_wait(self, async_client_ref, pool_name, slots_indexes, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['slots_indexes'] = slots_indexes
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.add_spares"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.add_spares_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def can_add_spares(self, pool_name, slots_list, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        params['slots_list'] = slots_list
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.can_add_spares"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['nb_spares']

    def can_add_spares_async(self, pool_name, slots_list, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        params['slots_list'] = slots_list
        url = "api/external/7.0/raid.RaidManagement.can_add_spares"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def can_change_mode(self, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.can_change_mode"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['future_mode']

    def can_change_mode_async(self, pool_name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        url = "api/external/7.0/raid.RaidManagement.can_change_mode"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def can_expand(self, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.can_expand"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['status']

    def can_expand_async(self, pool_name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        url = "api/external/7.0/raid.RaidManagement.can_expand"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def change_mode(self, async_client_ref, pool_name, future_mode, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['future_mode'] = future_mode
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.change_mode"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def change_mode_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/raid.RaidManagement.change_mode_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def change_mode_wait(self, async_client_ref, pool_name, future_mode, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['future_mode'] = future_mode
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.change_mode"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.change_mode_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def change_volume_management(self, pool_name, management, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        params['management'] = management
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.change_volume_management"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['pool']

    def change_volume_management_async(self, pool_name, management, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        params['management'] = management
        url = "api/external/7.0/raid.RaidManagement.change_volume_management"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def clear_migration_plan(self, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.clear_migration_plan"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 

    def clear_migration_plan_async(self, pool_name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        url = "api/external/7.0/raid.RaidManagement.clear_migration_plan"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def compute_raid_sizes(self, level_info, slots, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['level_info'] = level_info
        params['slots'] = slots
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.compute_raid_sizes"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['size_info']

    def compute_raid_sizes_async(self, level_info, slots, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['level_info'] = level_info
        params['slots'] = slots
        url = "api/external/7.0/raid.RaidManagement.compute_raid_sizes"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def configuration_pool_checker(self, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.configuration_pool_checker"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['slot_errors']

    def configuration_pool_checker_async(self, pool_name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        url = "api/external/7.0/raid.RaidManagement.configuration_pool_checker"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def create_pool(self, async_client_ref, list_of_slots, raid_mode, raid_level, redundancy_level, lv_management, __client__=None, timeout=None, raw_output=False):
        """
        raid_level: only used when raid_mode == RaidMode.MANUAL
        redundancy_level: only used when raid_mode ==RaidMode.OPTIMUM
        redundancy_level: else set to RedundancyLevel.UNKNOWN
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['list_of_slots'] = list_of_slots
        params['raid_mode'] = raid_mode
        params['raid_level'] = raid_level
        params['redundancy_level'] = redundancy_level
        params['lv_management'] = lv_management
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.create_pool"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def create_pool_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/raid.RaidManagement.create_pool_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def create_pool_wait(self, async_client_ref, list_of_slots, raid_mode, raid_level, redundancy_level, lv_management, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        """
        raid_level: only used when raid_mode == RaidMode.MANUAL
        redundancy_level: only used when raid_mode ==RaidMode.OPTIMUM
        redundancy_level: else set to RedundancyLevel.UNKNOWN
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['list_of_slots'] = list_of_slots
        params['raid_mode'] = raid_mode
        params['raid_level'] = raid_level
        params['redundancy_level'] = redundancy_level
        params['lv_management'] = lv_management
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.create_pool"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.create_pool_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def destroy_pool(self, async_client_ref, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.destroy_pool"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def destroy_pool_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/raid.RaidManagement.destroy_pool_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def destroy_pool_wait(self, async_client_ref, pool_name, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.destroy_pool"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.destroy_pool_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def expand(self, async_client_ref, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.expand"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def expand_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/raid.RaidManagement.expand_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def expand_wait(self, async_client_ref, pool_name, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.expand"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.expand_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def get_migration_plan(self, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.get_migration_plan"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['migration_plan']

    def get_migration_plan_async(self, pool_name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        url = "api/external/7.0/raid.RaidManagement.get_migration_plan"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_pool(self, pool_name, __client__=None, timeout=None, raw_output=False):
        """
        Returns None if Pool doesn't exists
        """
        params = dict()
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.get_pool"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['pool']

    def get_pool_async(self, pool_name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        url = "api/external/7.0/raid.RaidManagement.get_pool"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_pool_property(self, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.get_pool_property"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['pool']

    def get_pool_property_async(self, pool_name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        url = "api/external/7.0/raid.RaidManagement.get_pool_property"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_slot_property(self, slot_id, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['slot_id'] = slot_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.get_slot_property"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['slot']

    def get_slot_property_async(self, slot_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['slot_id'] = slot_id
        url = "api/external/7.0/raid.RaidManagement.get_slot_property"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def is_small_drive(self, index, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['index'] = index
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.is_small_drive"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['status']

    def is_small_drive_async(self, index, pool_name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['index'] = index
        params['pool_name'] = pool_name
        url = "api/external/7.0/raid.RaidManagement.is_small_drive"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list_migrations(self, pool_name, slots, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        params['slots'] = slots
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.list_migrations"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['raid_migrations']

    def list_migrations_async(self, pool_name, slots, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        params['slots'] = slots
        url = "api/external/7.0/raid.RaidManagement.list_migrations"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list_pools(self, with_parameters, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['with_parameters'] = with_parameters
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.list_pools"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['pools']

    def list_pools_async(self, with_parameters, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['with_parameters'] = with_parameters
        url = "api/external/7.0/raid.RaidManagement.list_pools"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list_raid_levels(self, slots, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['slots'] = slots
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.list_raid_levels"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['raid_levels']

    def list_raid_levels_async(self, slots, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['slots'] = slots
        url = "api/external/7.0/raid.RaidManagement.list_raid_levels"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list_slots(self, __client__=None, timeout=None, raw_output=False):
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.list_slots"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['list_slots']

    def list_slots_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/7.0/raid.RaidManagement.list_slots"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list_subsitute_slots(self, pool_name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['pool_name'] = pool_name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.list_subsitute_slots"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['slots_id']

    def list_subsitute_slots_async(self, pool_name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['pool_name'] = pool_name
        url = "api/external/7.0/raid.RaidManagement.list_subsitute_slots"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def maintenance_optimum_mode(self, async_client_ref, pool_name, index, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['index'] = index
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.maintenance_optimum_mode"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def maintenance_optimum_mode_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/raid.RaidManagement.maintenance_optimum_mode_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def maintenance_optimum_mode_wait(self, async_client_ref, pool_name, index, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['index'] = index
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.maintenance_optimum_mode"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.maintenance_optimum_mode_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def migrate_pool(self, async_client_ref, pool_name, slots, raid_mode, raid_level, redundancy_level, __client__=None, timeout=None, raw_output=False):
        """
        raid_level: only used when raid_mode == RaidMode.MANUAL
        redundancy_level: only used when raid_mode ==RaidMode.OPTIMUM
        redundancy_level: else set to RedundancyLevel.UNKNOWN
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['slots'] = slots
        params['raid_mode'] = raid_mode
        params['raid_level'] = raid_level
        params['redundancy_level'] = redundancy_level
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.migrate_pool"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def migrate_pool_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/raid.RaidManagement.migrate_pool_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def migrate_pool_wait(self, async_client_ref, pool_name, slots, raid_mode, raid_level, redundancy_level, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        """
        raid_level: only used when raid_mode == RaidMode.MANUAL
        redundancy_level: only used when raid_mode ==RaidMode.OPTIMUM
        redundancy_level: else set to RedundancyLevel.UNKNOWN
        """
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['slots'] = slots
        params['raid_mode'] = raid_mode
        params['raid_level'] = raid_level
        params['redundancy_level'] = redundancy_level
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.migrate_pool"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.migrate_pool_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')


    def replace_slot(self, async_client_ref, pool_name, index, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['index'] = index
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.replace_slot"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['async_job_id']


    def replace_slot_result(self, async_job_id,__client__=None, raw_output=False, timeout=None):
        params = dict()
        params['async_job_id'] = async_job_id

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__

        url = "api/external/7.0/raid.RaidManagement.replace_slot_result"
        context = ClientTransportSender.get_context('unicorn_api')
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 



    def replace_slot_wait(self, async_client_ref, pool_name, index, __client__=None, timeout=None, raw_output=False, nb_timeout=None, sleep=None, nb_poll=None):
        params = dict()
        params['async_client_ref'] = async_client_ref
        params['pool_name'] = pool_name
        params['index'] = index
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/raid.RaidManagement.replace_slot"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        async_job_id = res['async_job_id']
        res = ClientTransportSender.get_job_status(async_job_id)
        nbPoll = nb_poll if nb_poll is not None else 200
        nbTimeout = nb_timeout if nb_timeout is not None else 4
        sleepTime = sleep if sleep is not None else 3
        currentPoll = currentTimeout = 0
        while 2 == res.status and currentPoll < nbPoll:
            time.sleep(sleepTime)
            try:
                res = ClientTransportSender.get_job_status(async_job_id)
            except HTTPError, exc:
                if exc.status == "Timeout":
                    currentTimeout += 1
                    if currentTimeout >= nbTimeout:
                        raise
                    continue
            currentPoll += 1
        if 2 != res.status:
            return self.replace_slot_result(async_job_id, raw_output=raw_output)
        raise Exception('Failed to get result')
