#!/usr/bin/python
# -*- coding: utf-8 -*-

#                         LACIE CONFIDENTIAL
#
# The information contained in this file is the property of LACIE.
# The user of this file shall keep information contained herein confidential
# and shall protect it in whole or in part from disclosure and dissemination
# to third parties.
# Without prior written consent of LACIE, you may not reproduce, represent,
# or download through any means, the information contained herein in any way
# or in any form for a purpose other that the use for internal evaluation,
# operation or maintenance within LACIE.
#
#          (c) LACIE, 2009 - 2012, All Rights Reserved.

#GEN_DATE Jan 18 2016 15:24:02
#
# 888b. .d88b.    8b  8 .d88b. 88888    8888 888b. 888 88888
# 8   8 8P  Y8    8Ybm8 8P  Y8   8      8www 8   8  8    8
# 8   8 8b  d8    8  '8 8b  d8   8      8    8   8  8    8
# 888P' `Y88P'    8   8 `Y88P'   8      8888 888P' 888   8
#
#

import time
from transformer.lib import Optional
from unicorn_api.v7.sv0.sharing.Share import Share
from unicorn_api.v7.sv0.sharing import Access

from transformer.lib import List, ListInfo, ResultSet

from transformer.client_serializer import ClientSerializer
from transformer.lib.client import APIService


class Sharing(APIService):


    def _list(self, with_parameters, list_info, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/local/7.0/sharing.shares.Administration._list"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['share_list']

    def _list_async(self, with_parameters, list_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        url = "api/local/7.0/sharing.shares.Administration._list"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def add(self, share, volume_id, __client__=None, timeout=None, raw_output=False):
        """
        add a share
        """
        params = dict()
        params['share'] = share
        params['volume_id'] = volume_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/sharing.shares.Administration.add"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['share']

    def add_async(self, share, volume_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['share'] = share
        params['volume_id'] = volume_id
        url = "api/external/7.0/sharing.shares.Administration.add"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def check_name_availability(self, name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['name'] = name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/sharing.shares.Administration.check_name_availability"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['is_available']

    def check_name_availability_async(self, name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['name'] = name
        url = "api/external/7.0/sharing.shares.Administration.check_name_availability"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_max_shares_count(self, __client__=None, timeout=None, raw_output=False):
        params = dict()

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/sharing.shares.Administration.get_max_shares_count"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['max_count']

    def get_max_shares_count_async(self, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()

        url = "api/external/7.0/sharing.shares.Administration.get_max_shares_count"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def get_share_by_name(self, name, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['name'] = name
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/sharing.shares.Administration.get_share_by_name"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['share']

    def get_share_by_name_async(self, name, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['name'] = name
        url = "api/external/7.0/sharing.shares.Administration.get_share_by_name"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def list(self, with_parameters, list_info, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/sharing.shares.Administration.list"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['share_list']

    def list_async(self, with_parameters, list_info, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['with_parameters'] = with_parameters
        params['list_info'] = list_info
        url = "api/external/7.0/sharing.shares.Administration.list"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def modify(self, share_id, share, __client__=None, timeout=None, raw_output=False):
        params = dict()
        params['share_id'] = share_id
        params['share'] = share
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/sharing.shares.Administration.modify"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return res['share']

    def modify_async(self, share_id, share, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['share_id'] = share_id
        params['share'] = share
        url = "api/external/7.0/sharing.shares.Administration.modify"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)


    def remove(self, share_id, __client__=None, timeout=None, raw_output=False):
        """
        remove a share
        """
        params = dict()
        params['share_id'] = share_id
        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = self.__client__
        context = ClientTransportSender.get_context('unicorn_api')

        url = "api/external/7.0/sharing.shares.Administration.remove"
        success, resp = ClientTransportSender.send(url,ClientSerializer.to_string(context, params))
        if raw_output:
            return success, resp
        res = ClientSerializer.from_string(context, success, resp)
        return 

    def remove_async(self, share_id, callback, __client__=None):

        if __client__:
            ClientTransportSender = __client__
        else:
            ClientTransportSender = ClientTransport
        params = dict()
        params['share_id'] = share_id
        url = "api/external/7.0/sharing.shares.Administration.remove"
        context = ClientTransportSender.get_context('unicorn_api')
        ClientTransportSender.async(url, ClientSerializer.to_string(context, params), callback, context)
